@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require 'optparse'
 
 module YARD
@@ -41,8 +42,8 @@ module YARD
         opts.on_tail('--verbose', 'Show more information.') { log.level = Logger::INFO }
         opts.on_tail('--debug', 'Show debugging information.') { log.level = Logger::DEBUG }
         opts.on_tail('--backtrace', 'Show stack traces') { log.show_backtraces = true }
-        opts.on_tail('-v', '--version', 'Show version.') { puts "yard #{YARD::VERSION}"; exit }
-        opts.on_tail('-h', '--help', 'Show this help.')  { puts opts; exit }
+        opts.on_tail('-v', '--version', 'Show version.') { log.puts "yard #{YARD::VERSION}"; exit }
+        opts.on_tail('-h', '--help', 'Show this help.')  { log.puts opts; exit }
       end
 
       # Parses the option and gracefully handles invalid switches
@@ -54,8 +55,8 @@ module YARD
       def parse_options(opts, args)
         opts.parse!(args)
       rescue OptionParser::ParseError => err
-        log.warn "Unrecognized/#{err.message}"
-        args.shift if args.first && args.first[0,1] != '-'
+        unrecognized_option(err)
+        args.shift if args.first && args.first[0, 1] != '-'
         retry
       end
 
@@ -71,6 +72,14 @@ module YARD
         log.error "The file `#{file}' could not be loaded:\n#{load_exception}"
         exit
       end
+
+      # Callback when an unrecognize option is parsed
+      #
+      # @param [OptionParser::ParseError] err the exception raised by the
+      #   option parser
+      def unrecognized_option(err)
+        log.warn "Unrecognized/#{err.message}"
+      end
     end
   end
-end
\ No newline at end of file
+end
