@@ -11,6 +11,9 @@ module YARD
       # @private
       URLMATCH = /[^\w\s~!\*'\(\):;@&=\$,\[\]<>-]/
 
+      # @private
+      ASCIIDOC_ATTRIBUTES = {"env" => "yard", "env-yard" => ""}.freeze
+
       # @group Escaping Template Data
 
       # Escapes HTML entities
@@ -62,7 +65,7 @@ module YARD
           html = html.encode(:invalid => :replace, :replace => '?')
         end
         html = resolve_links(html)
-        unless [:text, :none, :pre].include?(markup)
+        unless [:text, :none, :pre, :ruby].include?(markup)
           html = parse_codeblocks(html)
         end
         html
@@ -75,12 +78,19 @@ module YARD
       def html_markup_markdown(text)
         # TODO: other libraries might be more complex
         provider = markup_class(:markdown)
-        if provider.to_s == 'RDiscount'
+        case provider.to_s
+        when  'RDiscount'
           provider.new(text, :autolink).to_html
-        elsif provider.to_s == 'RedcarpetCompat'
-          provider.new(text, :no_intraemphasis, :gh_blockcode,
-                             :fenced_code, :autolink, :tables,
-                             :lax_spacing).to_html
+        when 'RedcarpetCompat'
+          provider.new(text, :autolink,
+                             :fenced_code,
+                             :gh_blockcode,
+                             :lax_spacing,
+                             :tables,
+                             :with_toc_data,
+                             :no_intraemphasis).to_html
+        when 'CommonMarker'
+          CommonMarker.render_html(text, %i[DEFAULT GITHUB_PRE_LANG], %i[autolink])
         else
           provider.new(text).to_html
         end
@@ -97,7 +107,8 @@ module YARD
       # @param [String] text input Asciidoc text
       # @return [String] output HTML
       def html_markup_asciidoc(text)
-        markup_class(:asciidoc).render(text)
+        options = {:attributes => ASCIIDOC_ATTRIBUTES}
+        markup_class(:asciidoc).convert(text, options)
       end
 
       # Converts Textile to HTML
@@ -312,6 +323,9 @@ module YARD
         link = url_for(obj, anchor, relative)
         link = link ? link_url(link, title, :title => h("#{obj.title} (#{obj.type})")) : title
         "<span class='object_link'>" + link + "</span>"
+      rescue Parser::UndocumentableError
+        log.warn "The namespace of link #{obj.inspect} is a constant or invalid."
+        title || obj.to_s
       end
 
       # (see BaseHelper#link_url)
@@ -624,11 +638,13 @@ module YARD
       # @return [String] highlighted html
       # @see #html_syntax_highlight
       def parse_codeblocks(html)
-        html.gsub(%r{<pre\s*(?:lang="(.+?)")?>(?:\s*<code\s*(?:class="(.+?)")?\s*>)?(.+?)(?:</code>\s*)?</pre>}m) do
+        html.gsub(%r{<pre((?:\s+\w+="(?:.+?)")*)\s*>(?:\s*<code((?:\s+\w+="(?:.+?)")*)\s*>)?(.+?)(?:</code>\s*)?</pre>}m) do
           string = $3
+
           # handle !!!LANG prefix to send to html_syntax_highlight_LANG
           language, = parse_lang_for_codeblock(string)
-          language ||= $1 || $2 || object.source_type
+          language ||= detect_lang_in_codeblock_attributes($1, $2)
+          language ||= object.source_type
 
           if options.highlight
             string = html_syntax_highlight(CGI.unescapeHTML(string), language)
@@ -637,6 +653,21 @@ module YARD
           %(<pre class="#{classes}"><code class="#{language}">#{string}</code></pre>)
         end
       end
+
+      # Parses code block's HTML attributes in order to detect the programming
+      # language of what's enclosed in that code block.
+      #
+      # @param [String, nil] pre_html_attrs HTML attribute list of +pre+ element
+      # @param [String, nil] code_html_attrs HTML attribute list of +code+
+      #   element
+      # @return [String, nil] detected programming language
+      def detect_lang_in_codeblock_attributes(pre_html_attrs, code_html_attrs)
+        detected = nil
+        detected ||= (/\bdata-lang="(.+?)"/ =~ code_html_attrs && $1)
+        detected ||= (/\blang="(.+?)"/ =~ pre_html_attrs && $1)
+        detected ||= (/\bclass="(.+?)"/ =~ code_html_attrs && $1)
+        detected
+      end
     end
   end
 end
